###################################################
### chunk number 1: 
###################################################
options(width=72, prompt="R> ")


###################################################
### chunk number 2: 
###################################################
library("simFrame")
library("laeken")
data("eusilcP")


###################################################
### chunk number 3: 
###################################################
## define function for simulation runs
sim <- function(x, k) {
    x <- x[!is.na(x$eqIncome), ]
    g <- gini(x$eqIncome, x$.weight)$value
    eqIncHill <- fitPareto(x$eqIncome, k = k, 
        method = "thetaHill", groups = x$hid)
    gHill <- gini(eqIncHill, x$.weight)$value
    eqIncPDC <- fitPareto(x$eqIncome, k = k, 
        method = "thetaPDC", groups = x$hid)
    gPDC <- gini(eqIncPDC, x$.weight)$value
    c(standard = g, Hill = gHill, PDC = gPDC)
}


###################################################
### chunk number 4: 
###################################################
set.seed(12345)
## set up samples
sc <- SampleControl(grouping = "hid", size = 1500, k = 100)
#sc <- SampleControl(grouping = "hid", size = 1500, k = 6)
## run simulation
results <- runSimulation(eusilcP, sc, fun = sim, k = 175)


###################################################
### chunk number 5: 
###################################################
## show the first results
head(results)
## aggregate results
aggregate(results)
## compute true values
tv <- gini(eusilcP$eqIncome)$value
## plot results
plot(results, true = tv)


###################################################
### chunk number 6: 
###################################################
print(plot(results, true = tv))


###################################################
### chunk number 7: 
###################################################
set.seed(12345)
## set up samples
sc <- SampleControl(design = "region", grouping = "hid", 
    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 100)
#    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 6)
## run simulation
results <- runSimulation(eusilcP, sc, fun = sim, k = 175)


###################################################
### chunk number 8: 
###################################################
## show the first results
head(results)
## aggregate results
aggregate(results)
## compute true values
tv <- gini(eusilcP$eqIncome)$value
## plot results
plot(results, true = tv)


###################################################
### chunk number 9: 
###################################################
print(plot(results, true = tv))


###################################################
### chunk number 10: 
###################################################
set.seed(12345)
## set up samples
sc <- SampleControl(design = "region", grouping = "hid", 
    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 100)
#    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 6)
## define contamination
cc <- DCARContControl(target = "eqIncome", epsilon = 0.005, 
    grouping = "hid", dots = list(mean = 500000, sd = 10000))
## run simulation
results <- runSimulation(eusilcP, sc, 
    contControl = cc, fun = sim, k = 175)


###################################################
### chunk number 11: 
###################################################
## show the first results
head(results)
## aggregate results
aggregate(results)
## compute true values
tv <- gini(eusilcP$eqIncome)$value
## plot results
plot(results, true = tv)


###################################################
### chunk number 12: 
###################################################
print(plot(results, true = tv))


###################################################
### chunk number 13: 
###################################################
set.seed(12345)
## set up samples
sc <- SampleControl(design = "region", grouping = "hid", 
    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 100)
#    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 6)
## define contamination
cc <- DCARContControl(target = "eqIncome", epsilon = 0.005, 
    grouping = "hid", dots = list(mean = 500000, sd = 10000))
## run simulation
results <- runSimulation(eusilcP, sc, contControl = cc, 
    design = "gender", fun = sim, k = 125)


###################################################
### chunk number 14: 
###################################################
## show the first results
head(results)
## aggregate results
aggregate(results)
## compute true values
tv <- simSapply(eusilcP, "gender", function(x) gini(x$eqIncome)$value)
## plot results
plot(results, true = tv)


###################################################
### chunk number 15: 
###################################################
print(plot(results, true = tv))


###################################################
### chunk number 16: 
###################################################
set.seed(12345)
## set up samples
sc <- SampleControl(design = "region", grouping = "hid", 
    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 100)
#    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 6)
## define contamination
cc <- DCARContControl(target = "eqIncome", 
    epsilon = c(0, 0.0025, 0.005, 0.0075, 0.01),
    dots = list(mean = 500000, sd = 10000))
## run simulation
results <- runSimulation(eusilcP, sc, contControl = cc, 
    design = "gender", fun = sim, k = 125)


###################################################
### chunk number 17: 
###################################################
## show the first results
head(results)
## aggregate results
aggregate(results)
## compute true values
tv <- simSapply(eusilcP, "gender", function(x) gini(x$eqIncome)$value)
## plot results
plot(results, true = tv)


###################################################
### chunk number 18: 
###################################################
print(plot(results, true = tv))


###################################################
### chunk number 19: 
###################################################
set.seed(12345)
## set up samples
sc <- SampleControl(design = "region", grouping = "hid", 
    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 50)
#    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 6)
## define contamination
cc <- DCARContControl(target = "eqIncome", 
    epsilon = c(0, 0.005, 0.01), dots = list(mean = 500000, sd = 10000))
## define missing values
#nc <- NAControl(target = "eqIncome", 
#    NArate = c(0, 0.05), aux = "eqIncome")
nc <- NAControl(target = "eqIncome", NArate = c(0, 0.05))
## run simulation
results <- runSimulation(eusilcP, sc, contControl = cc, 
    NAControl = nc, design = "gender", fun = sim, k = 125)


###################################################
### chunk number 20: 
###################################################
## show the first results
head(results)
## aggregate results
aggregate(results)
## compute true values
tv <- simSapply(eusilcP, "gender", function(x) gini(x$eqIncome)$value)
## plot results
plot(results, true = tv)


###################################################
### chunk number 21: 
###################################################
print(plot(results, true = tv))


###################################################
### chunk number 22: 
###################################################
## start snow cluster
cl <- makeCluster(4, type="SOCK")
## load required packages on workers
clusterEvalQ(cl, {
        library("simFrame")
        library("laeken")
        data("eusilcP")
    })
## setup random number stream
clusterSetupRNG(cl, seed=12345)
## define samples
sc <- SampleControl(design = "region", grouping = "hid", 
    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 50)
#    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 6)
## define contamination
cc <- DCARContControl(target = "eqIncome", 
    epsilon = c(0, 0.005, 0.01), dots = list(mean = 500000, sd = 10000))
## define missing values
#nc <- NAControl(target = "eqIncome", 
#    NArate = c(0, 0.05), aux = "eqIncome")
nc <- NAControl(target = "eqIncome", NArate = c(0, 0.05))
## export object to workers
clusterExport(cl, c("sc", "cc", "nc", "sim"))
## run simulation
results <- clusterRunSimulation(cl, eusilcP, sc, 
    contControl = cc, NAControl = nc, design = "gender", 
    fun = sim, k = 125)
## stop snow cluster
stopCluster(cl)


###################################################
### chunk number 23: 
###################################################
## show the first results
head(results)
## aggregate results
aggregate(results)
## compute true values
tv <- simSapply(eusilcP, "gender", function(x) gini(x$eqIncome)$value)
## plot results
plot(results, true = tv)


###################################################
### chunk number 24: 
###################################################
print(plot(results, true = tv))


